﻿
using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Dynamic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace GxGFanShared
{
    public class MainViewModel : WiewModelBase
    {
        IFacebookClient _client;
        string _uid = "me()";
        private ObservableCollection<Album> _album;
        public MainViewModel(IFacebookClient client, string uid)
        {
            if (client == null) throw new ArgumentNullException("client");
            _uid = string.IsNullOrEmpty(uid) ? _uid : uid;
            _client = client;
            GetAlbumAsync();
        }

        private async void GetAlbumAsync()
        {
            IsBusy = true;
            try
            {
                //recuperò le immagini di copertina degli album
                dynamic parameters = new ExpandoObject();
                var query = string.Format(FQLRepository.AlbumCoverQuery, _uid);
                parameters.q = query;
                var pictureResult = ((IEnumerable<dynamic>)(await _client.GetTaskAsync("fql", parameters)).data)
                    .Select(item => new Photo
                    {
                        PhotoID = item["pid"],
                        AlbumID = item["aid"],
                        BigPhotoUri = item["src_big"],
                        SmallPhotoUri = item["src_small"]

                    }).ToList();

                //recupero l'album
                query = string.Format(FQLRepository.AlbumQuery, _uid);
                parameters = new ExpandoObject();
                parameters.q = query;


                dynamic albumResult = await _client.GetTaskAsync("fql", parameters);
                foreach (var item in albumResult.data)
                {
                    Albums.Add(new Album
                    {
                        Name = item["name"],
                        AlbumID = item["aid"],
                        CoverPhotoID = item["cover_pid"],
                        PhotoCount = item["photo_count"],
                        SmallPhotoUri = pictureResult.Where(p => p.PhotoID == (string)item["cover_pid"]).Select(p => p.SmallPhotoUri).FirstOrDefault(),
                        BigPhotoUri = pictureResult.Where(p => p.PhotoID == (string)item["cover_pid"]).Select(p => p.BigPhotoUri).FirstOrDefault()
                    });
                }
            }
            catch (Exception ex)
            {
                if (ex is IFacebookApiException)
                {
                }
            }
            finally
            {
                IsBusy = false;
            }

        }
        public ObservableCollection<Album> Albums
        {
            get
            {
                if (_album == null)
                {
                    _album = new ObservableCollection<Album>();
                }
                return _album;
            }
        }
    }
}
